@@ -1,3 +1,24 @@
+## A helper function to reorder vector v (if named) into order
+## specified by names. Copied from ergm::ergm.model.utils.R.
+vector.namesmatch<-function(v,names,errname=NULL){
+  if(is.null(errname)) errname <- deparse(substitute(v))
+
+  if (is.null(names(v))){
+    if(length(v) == length(names)){
+      names(v) <- names
+    }else stop('Length of "', errname, '" is ', length(v), " but should be ", length(names),".")
+  }else{
+    if(length(v) == length(names)
+       && length(unique(names(v)))==length(v)
+       && length(unique(names))==length(names)
+       && all(sort(names(v)) == sort(names))){
+      namesmatch <- match(names, names(v))
+      v <- v[namesmatch]
+    }else stop('Name missmatch in "', errname,'". Specify by position.')
+  }
+  v
+}
+
 ## Compress a data frame by eliminating duplicate rows while keeping
 ## track of their frequency.
 compress.data.frame<-function(x){
